::: openaq.shared.exceptions
    options:
      heading_level: 2
      members:
        - BadRequestError
        - NotAuthorized
        - Forbidden
        - NotFoundError
        - ValidationError
        - RateLimit
        - ServerError
        - GatewayTimeoutError
      show_root_heading: false
      show_source: false